bci_100: BCI 50 ha plot census data with 100m square quadrats

Description Usage Format Source Examples

Description

A table with one record per tree species per grid square per census, detailing the count of the species in that grid square for that census. In this case we use 100m square quadrats.

Usage

1

Format

A tbl data_frame

https://repository.si.edu/bitstream/handle/10088/20925/bci.full.Rdata31Aug2012.zip

Examples

1
2
3
4
5
6
7
8
9
  library(tibble)
  library(magrittr)
  library(dplyr)

  # How many trees in each census?
  bci_100 %>% group_by(census) %>% summarise(total=sum(count))

  # Look at the first quadrat of the first census
  bci_100 %>% filter(x==0, y==0, census==1)

boydorr/BCI documentation built on May 23, 2019, 4:24 p.m.