Description Usage Format Details Source Examples
A matrix of similarities between species based on their taxonomy. If the similarity is at a given level, and no higher, then this is the similarity:
1 |
A matrix
species_similarity <- 1 genus_similarity <- 0.75 family_similarity <- 0.5 subclass_similarity <- 0.25 # we use "order" instead of "subclass" other_similarity <- 0
https://repository.si.edu/bitstream/handle/10088/20925/bci.full.Rdata31Aug2012.zip
1 2 | # Show the similarity matrix for the first 3 species
bci_similarity[1:3, 1:3]
|
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.