bci_taxonomy: BCI 50 ha plot taxonomy

Description Usage Format Source Examples

Description

A table with one record per tree species detailing all of the taxonomic information about those species.

Usage

1

Format

A tbl data_frame

https://repository.si.edu/bitstream/handle/10088/20925/bci.full.Rdata31Aug2012.zip

Examples

1
2
3
4
  library(tibble)

  # Show the taxonomy
  bci_taxonomy

boydorr/BCI documentation built on May 23, 2019, 4:24 p.m.