gen_zmatrix: Generate similarity matrix for a given taxonomy

Usage Arguments Value Examples

Usage

1
2
gen_zmatrix(tax = BCI::bci_taxonomy, species = 1, genus = 0.75,
  family = 0.5, order = 0.25, other = 0)

Arguments

tax

The taxonomy to use

species

The similarity value if two rows are the same species

genus

The similarity value if two rows are the same genus but not species

family

The similarity value if two rows are the same family but not genus

order

The similarity value if two rows are the same order but not family

other

The similarity value if two rows are not the same order

Value

A matrix of similarities between species based on their taxonomy.

Examples

1
2
# Generate the similarity matrix for the BCI dataset
gen_zmatrix()

boydorr/BCI documentation built on May 23, 2019, 4:24 p.m.