Description Usage Format Source Examples
A table with one record per tree species per grid square per census, detailing the count of the species in that grid square for that census. In this case we use 100m square quadrats.
1 |
A tbl data_frame
https://repository.si.edu/bitstream/handle/10088/20925/bci.full.Rdata31Aug2012.zip
1 2 3 4 5 6 7 8 9 |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.