Description Usage Format Source Examples
A table with one record per tree species detailing all of the taxonomic information about those species.
1 |
A tbl data_frame
https://repository.si.edu/bitstream/handle/10088/20925/bci.full.Rdata31Aug2012.zip
1 2 3 4 | library(tibble)
# Show the taxonomy
bci_taxonomy
|
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.